--
--      Copyright 2015 Andrea Micheloni <a4a@m7i.org>
--
--    This program is free software: you can redistribute it and/or modify
--    it under the terms of the GNU General Public License as published by
--    the Free Software Foundation, either version 3 of the License, or
--    (at your option) any later version.
--
--    This program is distributed in the hope that it will be useful,
--    but WITHOUT ANY WARRANTY; without even the implied warranty of
--    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
--    GNU General Public License for more details.
--
--    You should have received a copy of the GNU General Public License
--    along with this program.  If not, see <http://www.gnu.org/licenses/>.
--

-- Parses a generic enumeration, tries to set the node attribute if successful.
function ui_enumerate(node, data, value, known_values)
    local label = node.get_attribute(node, 'label')

    log.print(log.DEBUG, "Trying to find the description of type " .. label .. " for value " .. value)

    nodes.set_attribute(node, 'val', data)

    local result = known_values[value]

    if result then
        nodes.set_attribute(node, "alt", result)
        log.print(log.DEBUG, "Description of type " .. label .. " for value " .. value .. " is " .. result)
    else
        log.print(log.WARNING, "Description of type " .. label .. " for value " .. value .. " unknown.")
    end
end

-- Parses a card application type
function ui_parse_card_application_type(node, data) 
    return ui_enumerate(node, data, bytes.tonumber(data), 
        { [0x00] = "Administrative and Emergency Clinical", [0x01] = "Administrative" , [0x02] = "Emergency Clinical", [0x09] = "Local use"})
end

-- Parse card status
function ui_parse_card_status(node, data)
    return ui_enumerate(node, data, bytes.tonumber(data), 
        { [0x00] = "Unknown", [0x01] = "Test card" , [0x02] = "Normal"})
end

-- Parses a donor organ category
function ui_parse_organ_category(node, data) 
    return ui_enumerate(node, data, bytes.tonumber(data), 
        { [0x01] = "Heart", [0x02] = "Lungs", [0x03] = "Liver", [0x04] = "Kidneys", [0x05] = "Pancreas", [0x06] = "Tissues", [0x99] = "Everything"})
end

-- Parses a donor choice 1=yes, 2=no, 3=ask a third party
function ui_parse_organ_donor_choice(node, data) 
    return ui_enumerate(node, data, bytes.tonumber(data), 
        { [0x01] = "Yes", [0x02] = "No" , [0x03] = "Ask a third party"})
end

-- Parse doctor qualification: 0=family doctor, 1=pediatrician, 2=other
function ui_parse_doctor_qualification(node, data)
    return ui_enumerate(node, data, bytes.tonumber(data), 
        { [0x00] = "Family Doctor", [0x01] = "Pediatrician" , [0x02] = "Other type"})
end

-- Parses a gender 0=unknown, 1=male, 2=female
function ui_parse_gender(node, data) 
    return ui_enumerate(node, data, bytes.tonumber(data), 
        { [0x00] = "Unknown", [0x01] = "Male" , [0x02] = "Female"})
end
