--
--      Copyright 2015 Andrea Micheloni <a4a@m7i.org>
--
--    This program is free software: you can redistribute it and/or modify
--    it under the terms of the GNU General Public License as published by
--    the Free Software Foundation, either version 3 of the License, or
--    (at your option) any later version.
--
--    This program is distributed in the hope that it will be useful,
--    but WITHOUT ANY WARRANTY; without even the implied warranty of
--    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
--    GNU General Public License for more details.
--
--    You should have received a copy of the GNU General Public License
--    along with this program.  If not, see <http://www.gnu.org/licenses/>.
--

-- Loads the localisation for a particolar country code, if available.
function load_country_l10n(country)
	log.print(log.LOG_DEBUG, "Trying to load the localisation for country code " .. country)

    filename = "netlink/l10n/" .. country .. ".lua"
	file = io.open(filename);
	if file then 
		io.close(file)
		dofile(filename)

	    log.print(log.LOG_INFO, "Loaded the localisation for country code " .. country)
	else
		log.print(log.LOG_WARNING, "Could not find " .. filename)
	end
end

-- Parses a regional code - per-nation setting
function ui_parse_regional_code(node, data) 
    if ui_parse_regional_code_localised then
        ui_parse_regional_code_localised(node, data)
    else
        log.print(log.WARNING, "No nation-specific localisation for ui_parse_regional_code available.")
        ui_parse_printable(node, data)
    end
end

-- Parses a doctor organisation code - per-nation setting
function ui_parse_doctor_organisation_code(node, data) 
    if ui_parse_doctor_organisation_code_localised then
        ui_parse_doctor_organisation_code_localised(node, data)
    else
        log.print(log.WARNING, "No nation-specific localisation for ui_parse_doctor_organisation_code available.")
        ui_parse_printable(node, data)
    end
end

-- Parses a issuer code - per-nation setting
function ui_parse_issuer_code(node, data) 
    if ui_parse_issuer_code_localised then
        ui_parse_issuer_code_localised(node, data)
    else
        log.print(log.WARNING, "No nation-specific localisation for ui_parse_issuer_code available.")
        ui_parse_printable(node, data)
    end
end

-- Parses a card issuer code - per-nation setting
function ui_parse_card_issuer_code(node, data) 
    if ui_parse_card_issuer_code_localised then
        ui_parse_card_issuer_code_localised(node, data)
    else
        log.print(log.WARNING, "No nation-specific localisation for ui_parse_card_issuer_code available.")
        ui_parse_printable(node, data)
    end
end

-- Parses the actual nation-specific card serial number - per-nation setting
function ui_parse_actual_serial_number(node, data) 
    if ui_parse_actual_serial_number_localised then
        ui_parse_actual_serial_number_localised(node, data)
    else
        log.print(log.WARNING, "No nation-specific localisation for ui_parse_actual_serial_number available.")
    end
end
