--
--      Copyright 2015 Andrea Micheloni <a4a@m7i.org>
--
--    This program is free software: you can redistribute it and/or modify
--    it under the terms of the GNU General Public License as published by
--    the Free Software Foundation, either version 3 of the License, or
--    (at your option) any later version.
--
--    This program is distributed in the hope that it will be useful,
--    but WITHOUT ANY WARRANTY; without even the implied warranty of
--    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
--    GNU General Public License for more details.
--
--    You should have received a copy of the GNU General Public License
--    along with this program.  If not, see <http://www.gnu.org/licenses/>.
--
-- Italian (380) specific localizations for Netlink
--
-- Specification source: http://www.agid.gov.it/agenda-digitale/infrastrutture-architetture/carta-nazionale-servizi/specifiche-tecniche
-- The documents on the original website are licensed (http://www.agid.gov.it/note-legali) under the CC-BY 3.0 (http://creativecommons.org/licenses/by/3.0/it/)
--
-- Specification of the serial number: http://www.agid.gov.it/sites/default/files/documentazione/sn_29.pdf
--

-- Parses the actual nation-specific card serial number - per-nation setting
function ui_parse_actual_serial_number_localised(node, data)
    local serial=tostring(data)

    local card_type = string.sub(serial, 1, 1)
    local found_type = TIPO_CARTA[card_type];

    if found_type then
        node:append{ classname="block", label="Tipo di carta", val=card_type, alt=found_type[1] }

        local parser = found_type[2]

        if parser then
            parser(node, serial)
        end
    else
        log.print(log.WARNING, "Tipo di carta " .. card_type .. " non trovato")
    end
end

-- Decodifica il campo della diffusione nazionale CN, nel caso di diffusione nazionale, e richiama i campi comuni
function decodifica_diffusione_nazionale(node, serial)
    local ente_nazionale = string.sub(serial, 2, 4)
    local trovato = DIFFUSIONE_NAZIONALE[ente_nazionale];

    local aggiunto = node:append{ classname="block", label="Codice emettitore nazionale", val=ente_nazionale }

    if trovato then
        nodes.set_attribute(aggiunto, 'val', trovato)
    else
        log.print(log.WARNING, "Ente nazionale con codice " .. ente_nazionale .. " non trovato")
    end

    decodifica_fine_comune(node, serial)
end

-- Decodifica il campo della diffusione regionale CR, nel caso di diffusione regionale, e richiama i campi comuni
function decodifica_diffusione_regionale(node, serial)
    local ente_regionale = string.sub(serial, 2, 4)
    local trovato = CODICI_ENTI_ASL[ente_regionale]

    local aggiunto = node:append{ classname="block", label="Codice emettitore regionale", val=ente_regionale }

    if trovato then
        nodes.set_attribute(aggiunto, 'val', trovato)
    else
        log.print(log.WARNING, "Ente regionale con codice " .. ente_regionale .. " non trovato")
    end

    decodifica_fine_comune(node, serial)
end

-- Decodifica i campi CI, PS e CD per carte a diffusione regionale e nazionale
function decodifica_fine_comune(node, serial)
    local identificativo = string.sub(serial, 5, 13)
    local progressivo = string.sub(serial, 14, 14);

    node:append{ classname="block", label="Codice identificativo (nell' ente)", val=identificativo, alt=identificativo }
    node:append{ classname="block", label="Codice progressivo", val=progressivo, alt=progressivo }
end

-- Decodifica i campi della diffusione locale CL1 e CL2, nel caso di diffusione locale
function decodifica_diffusione_local(node, serial)
    local codice_locale_1 = string.sub(serial, 2, 4)
    local codice_locale_1 = node:append{ classname="block", label="Codice emettitore", val=codice_locale_1 }

    local codice_locale_2 = string.sub(serial, 5, 7)
    local codice_locale_2 = node:append{ classname="block", label="Codice emettitore locale", val=codice_locale_2 }

    local identificativo = string.sub(serial, 8, 15)
    node:append{ classname="block", label="Codice identificativo (nell' ente)", val=identificativo, alt=identificativo }
end

TIPO_CARTA = {
    ["0"] = { "Tipo di carta riservato per uso futuro" }, 
    ["1"] = { "Carta per il cittadino, sperimentazione senza controllo del serial number" }, 
    ["2"] = { "Carta per il cittadino, sperimentazione senza controllo del serial number" }, 
    ["3"] = { "Carta operatore, sperimentazione senza controllo del serial number" }, 
    ["4"] = { "Carta operatore, sperimentazione senza controllo del serial number" }, 
    ["5"] = { "Carta per il cittadino, a diffusione nazionale", decodifica_diffusione_nazionale }, 
    ["6"] = { "Carta per il cittadino, a diffusione regionale", decodifica_diffusione_regionale }, 
    ["7"] = { "Carta per il cittadino con altra diffusione", decodifica_diffusione_locale }, 
    ["8"] = { "Carta operatore, a diffusione nazionale", decodifica_diffusione_nazionale }, 
    ["9"] = {"Carta operatore, a diffusione regionale", decodifica_diffusione_regionale }, 
}

DIFFUSIONE_NAZIONALE = {
    ["901"] = "Presidenza del Consiglio dei Ministri",
    ["902"] = "Ministero Economia e Finanze",
    ["903"] = "Ministero Attività Produttive",
    ["904"] = "Ministero Lavoro e Politiche sociali",
    ["905"] = "Ministero Giustizia",
    ["906"] = "Ministero Affari esteri",
    ["907"] = "Ministero Istruzione, Università e Ricerca",
    ["908"] = "Ministero Interno (*)",
    ["909"] = "Ministero Ambiente e tutela del territorio",
    ["910"] = "Ministero Infrastrutture e trasporti",
    ["911"] = "Ministero Comunicazioni",
    ["912"] = "Ministero Difesa",
    ["913"] = "Ministero Politiche agricole e forestali",
    ["914"] = "Ministero Beni e attività culturali",
    ["915"] = "Ministero della Salute",
    ["801"] = "ACI",
    ["802"] = "ASI",
    ["803"] = "CNR",
    ["804"] = "CONI",
    ["805"] = "CRI",
    ["806"] = "ENEA",
    ["807"] = "ICE",
    ["808"] = "INAIL",
    ["809"] = "INPDAP",
    ["810"] = "INPS",
    ["811"] = "INEA",
    ["812"] = "INFM",
    ["813"] = "INFN",
    ["814"] = "INPDAI",
    ["815"] = "ISS",
    ["816"] = "ISAE",
    ["817"] = "ISTAT",
    ["819"] = "ISPESL",
    ["820"] = "Monopoli di Stato",
    ["821"] = "Poste",
    ["822"] = "Autorità per le garanzie delle Comunicazioni",
    ["823"] = "Autorità per la vigilanza sui lavori pubblici",
    ["823"] = "Scuola Superiore Pubblica Amministrazione",
    ["701"] = "Stato Maggiore Difesa",
    ["702"] = "Stato Maggiore Esercito",
    ["703"] = "Stato Maggiore Marina",
    ["704"] = "Stato Maggiore Aeronautica",
    ["705"] = "Arma dei Carabinieri",
    ["706"] = "Guardia di Finanza",
    ["707"] = "Polizia di Stato",
    ["708"] = "Polizia Penitenziaria",
    ["709"] = "Corpo Forestale dello Stato",
    ["710"] = "DIA",
    ["601"] = "Avvocatura generale dello Stato",
    ["602"] = "AGEA",
    ["603"] = "Agenzia Demanio",
    ["604"] = "Agenzia Dogane",
    ["605"] = "Agenzia Territorio",
    ["606"] = "Agenzia Segretari Comunali",
    ["607"] = "Agenzia Protezione Ambiente",
    ["608"] = "CNIPA",
    ["609"] = "Consiglio di Stato",
    ["610"] = "CONSOB",
    ["611"] = "Corte dei Conti",
    ["612"] = "ENAC",
    ["613"] = "ENIT",
    ["614"] = "ENPALS",
    ["615"] = "ERSAT",
    ["616"] = "FIGC",
    ["617"] = "INEA",
    ["618"] = "IPOST",
    ["619"] = "IPSEMA",
    ["620"] = "INGV",
    ["621"] = "Istituto Poligrafico e Zecca dello Stato",
    ["622"] = "ISTAT",
    ["623"] = "ISS",
    ["624"] = "CNN",
    ["625"] = "ENPAF",
    ["626"] = "Istituto Italiano di Medicina sociale",
    ["627"] = "Consiglio nazionale Ordine dei Giornalisti",
    ["628"] = "Consiglio nazionale Ordine degli Ingegneri",
    ["629"] = "Collegio Nazionale degli Agrotecnici",
    ["630"] = "Consiglio Nazionale degli Architetti",
    ["631"] = "Consiglio Nazionale dei Chimici",
    ["632"] = "Consiglio Nazionale dei Dottori Commercialisti",
    ["633"] = "Consiglio Nazionale Forense",
    ["634"] = "Consiglio Nazionale dei Geologi",
    ["635"] = "Consiglio Nazionale del Notariato",
    ["636"] = "Consiglio Nazionale dei Ragionieri Commercialisti ed Economisti d'Impresa",
    ["637"] = "Ordine degli Avvocati",
    ["638"] = "Ordine dei Dottori Agronomi e dei Dottori Forestali",
    ["639"] = "Ordine dei Consulenti in proprietà industriale",
    ["640"] = "Ordine dei Medici Veterinari",
    ["641"] = "Ordine dei Veterinari",
    ["642"] = "Ordine Nazionale degli Psicologi",
    ["643"] = "Ordine Nazionale dei Consulenti del Lavoro",
    ["644"] = "Ordine Nazionale dei Dottori Agronomi e Dottori Forestali",
    ["645"] = "Ordine Tecnologi Alimentari",
    ["646"] = "Ordini dei Dottori Commercialisti",
    ["647"] = "Istituto Zooprofilattico Sperimentale",
    ["648"] = "Garante per la protezione dei dati personali",
    ["649"] = "Agenzia delle Entrate",
    ["650"] = "Consiglio Nazionale dei Geometri e Geometri Laureati",
    ["651"] = "Consiglio Nazionale dell’Economia e del Lavoro",
    ["100"] = "Ministero Interno"
}
